@@ -1,9 +1,10 @@
 from django.contrib import admin
 
-from apps.accounts.models import Site, Membership
+from apps.accounts.models import Membership, Site
+
 
 class SiteModelAdmin(admin.ModelAdmin):
-    list_display = ("id", "title", "slug", "share", "created_by")
+    list_display = ("id", "title", "slug", "created_by")
 
     class Meta:
         model = Site
@@ -11,6 +12,7 @@ class SiteModelAdmin(admin.ModelAdmin):
 
 admin.site.register(Site, SiteModelAdmin)
 
+
 class MembershipModelAdmin(admin.ModelAdmin):
     list_display = ("id", "user", "host", "rights")
 
@@ -19,4 +21,3 @@ class MembershipModelAdmin(admin.ModelAdmin):
 
 
 admin.site.register(Membership, MembershipModelAdmin)
-
