@@ -1,7 +1,8 @@
+import os
 import json
 import logging
 import platform
-
+import requests
 import nbformat
 
 from widgets.manager import WidgetsManager
@@ -13,7 +14,17 @@ CLIENT_SITE = "client"
 WORKER_SITE = "worker"
 
 
+my_ip = None
+
+
 def machine_uuid():
+    global my_ip
+    if my_ip is not None:
+        return my_ip
+    if os.environ.get("USE_WORKER_IP") is not None:
+        response = requests.get("https://api.ipify.org?format=json")
+        my_ip = response.json().get("ip", platform.node())
+        return my_ip
     return platform.node()
 
 
