@@ -16,6 +16,8 @@ class MultiSelect:
         self.code_uid = WidgetsManager.get_code_uid("MultiSelect")
         self.url_key = url_key
         self.hidden = hidden
+        choices = list(choices)
+        value = list(value)
         if WidgetsManager.widget_exists(self.code_uid):
             self.select = WidgetsManager.get_widget(self.code_uid)
             if list(self.select.options) != choices:
@@ -70,14 +72,14 @@ class MultiSelect:
                 "code_uid": self.code_uid,
                 "url_key": self.url_key,
                 "disabled": self.select.disabled,
-                "hidden": self.hidden
+                "hidden": self.hidden,
             }
             data["application/mercury+json"] = json.dumps(view, indent=4)
             if "text/plain" in data:
                 del data["text/plain"]
 
             if self.hidden:
-                key = 'application/vnd.jupyter.widget-view+json'
+                key = "application/vnd.jupyter.widget-view+json"
                 if key in data:
                     del data[key]
 
