@@ -7,7 +7,17 @@ from .manager import WidgetException, WidgetsManager
 
 
 class Numeric:
-    def __init__(self, value=0, min=0, max=10, label="", step=1, url_key="", disabled=False, hidden=False):
+    def __init__(
+        self,
+        value=0,
+        min=0,
+        max=10,
+        label="",
+        step=1,
+        url_key="",
+        disabled=False,
+        hidden=False,
+    ):
         if value < min:
             raise WidgetException("value should be equal or larger than min")
         if value > max:
@@ -37,7 +47,7 @@ class Numeric:
                 description=label,
                 step=step,
                 style={"description_width": "initial"},
-                disabled=disabled
+                disabled=disabled,
             )
             WidgetsManager.add_widget(
                 self.numeric.model_id, self.code_uid, self.numeric
@@ -76,14 +86,14 @@ class Numeric:
                 "code_uid": self.code_uid,
                 "url_key": self.url_key,
                 "disabled": self.numeric.disabled,
-                "hidden": self.hidden
+                "hidden": self.hidden,
             }
             data["application/mercury+json"] = json.dumps(view, indent=4)
             if "text/plain" in data:
                 del data["text/plain"]
 
             if self.hidden:
-                key = 'application/vnd.jupyter.widget-view+json'
+                key = "application/vnd.jupyter.widget-view+json"
                 if key in data:
                     del data[key]
 
